==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperTableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * CDC table details.
 * @property dslConnectorProperties List of name/value pairs for connection properties.
 * @property name Name of the table.
 * @property schema List of columns for the source table.
 */
public data class MapperTableArgs(
    public val dslConnectorProperties: Output<List<MapperDslConnectorPropertiesArgs>>? = null,
    public val name: Output<String>? = null,
    public val schema: Output<List<MapperTableSchemaArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperTableArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperTableArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperTableArgs.builder()
            .dslConnectorProperties(
                dslConnectorProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .schema(
                schema?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MapperTableArgs].
 */
@PulumiTagMarker
public class MapperTableArgsBuilder internal constructor() {
    private var dslConnectorProperties: Output<List<MapperDslConnectorPropertiesArgs>>? = null

    private var name: Output<String>? = null

    private var schema: Output<List<MapperTableSchemaArgs>>? = null

    /**
     * @param value List of name/value pairs for connection properties.
     */
    @JvmName("nljvokxoykgvcvqk")
    public suspend
    fun dslConnectorProperties(`value`: Output<List<MapperDslConnectorPropertiesArgs>>) {
        this.dslConnectorProperties = value
    }

    @JvmName("iemnkjnuvnfqnwwu")
    public suspend fun dslConnectorProperties(
        vararg
        values: Output<MapperDslConnectorPropertiesArgs>,
    ) {
        this.dslConnectorProperties = Output.all(values.asList())
    }

    /**
     * @param values List of name/value pairs for connection properties.
     */
    @JvmName("cptjmekvakcwyhnv")
    public suspend
    fun dslConnectorProperties(values: List<Output<MapperDslConnectorPropertiesArgs>>) {
        this.dslConnectorProperties = Output.all(values)
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("oqytnemiowfnfjnv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of columns for the source table.
     */
    @JvmName("pfyfdjsshefagbep")
    public suspend fun schema(`value`: Output<List<MapperTableSchemaArgs>>) {
        this.schema = value
    }

    @JvmName("yjnqculditqtuvwx")
    public suspend fun schema(vararg values: Output<MapperTableSchemaArgs>) {
        this.schema = Output.all(values.asList())
    }

    /**
     * @param values List of columns for the source table.
     */
    @JvmName("uapmpibvajotcoqq")
    public suspend fun schema(values: List<Output<MapperTableSchemaArgs>>) {
        this.schema = Output.all(values)
    }

    /**
     * @param value List of name/value pairs for connection properties.
     */
    @JvmName("pxepupbjqhvsregh")
    public suspend fun dslConnectorProperties(`value`: List<MapperDslConnectorPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("tnqpnkjyfqaatmnf")
    public suspend
    fun dslConnectorProperties(argument: List<suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("vpyoopmnnevcrkdl")
    public suspend fun dslConnectorProperties(
        vararg
        argument: suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("uonhjjfyoprrgbrp")
    public suspend
    fun dslConnectorProperties(argument: suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param values List of name/value pairs for connection properties.
     */
    @JvmName("mptgupuqciteqdis")
    public suspend fun dslConnectorProperties(vararg values: MapperDslConnectorPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dslConnectorProperties = mapped
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("rrxwocoicnhjclig")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of columns for the source table.
     */
    @JvmName("xjvcvilujnhjtrlq")
    public suspend fun schema(`value`: List<MapperTableSchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("uimheokfyycnqbwi")
    public suspend fun schema(argument: List<suspend MapperTableSchemaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MapperTableSchemaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("ogmoudewqsmebeme")
    public suspend fun schema(vararg argument: suspend MapperTableSchemaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MapperTableSchemaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("wgtlttwsgevlelbh")
    public suspend fun schema(argument: suspend MapperTableSchemaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MapperTableSchemaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param values List of columns for the source table.
     */
    @JvmName("cmsnfprarhhooqrx")
    public suspend fun schema(vararg values: MapperTableSchemaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schema = mapped
    }

    internal fun build(): MapperTableArgs = MapperTableArgs(
        dslConnectorProperties = dslConnectorProperties,
        name = name,
        schema = schema,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperTableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * CDC table details.
 * @property dslConnectorProperties List of name/value pairs for connection properties.
 * @property name Name of the table.
 * @property schema List of columns for the source table.
 */
public data class MapperTableArgs(
    public val dslConnectorProperties: Output<List<MapperDslConnectorPropertiesArgs>>? = null,
    public val name: Output<String>? = null,
    public val schema: Output<List<MapperTableSchemaArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperTableArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperTableArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperTableArgs.builder()
            .dslConnectorProperties(
                dslConnectorProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .schema(
                schema?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MapperTableArgs].
 */
@PulumiTagMarker
public class MapperTableArgsBuilder internal constructor() {
    private var dslConnectorProperties: Output<List<MapperDslConnectorPropertiesArgs>>? = null

    private var name: Output<String>? = null

    private var schema: Output<List<MapperTableSchemaArgs>>? = null

    /**
     * @param value List of name/value pairs for connection properties.
     */
    @JvmName("qdjnqxnshmbuaqfk")
    public suspend
    fun dslConnectorProperties(`value`: Output<List<MapperDslConnectorPropertiesArgs>>) {
        this.dslConnectorProperties = value
    }

    @JvmName("jiwfmgxspqpxitln")
    public suspend fun dslConnectorProperties(
        vararg
        values: Output<MapperDslConnectorPropertiesArgs>,
    ) {
        this.dslConnectorProperties = Output.all(values.asList())
    }

    /**
     * @param values List of name/value pairs for connection properties.
     */
    @JvmName("lmcprjnliumwfcei")
    public suspend
    fun dslConnectorProperties(values: List<Output<MapperDslConnectorPropertiesArgs>>) {
        this.dslConnectorProperties = Output.all(values)
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("xvaddivrawerrhib")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value List of columns for the source table.
     */
    @JvmName("ndaqcfcbwardiwgo")
    public suspend fun schema(`value`: Output<List<MapperTableSchemaArgs>>) {
        this.schema = value
    }

    @JvmName("cmrppvhgsefciqdd")
    public suspend fun schema(vararg values: Output<MapperTableSchemaArgs>) {
        this.schema = Output.all(values.asList())
    }

    /**
     * @param values List of columns for the source table.
     */
    @JvmName("cnhitwiirkdgvdvo")
    public suspend fun schema(values: List<Output<MapperTableSchemaArgs>>) {
        this.schema = Output.all(values)
    }

    /**
     * @param value List of name/value pairs for connection properties.
     */
    @JvmName("idgdbhxriavxhuxi")
    public suspend fun dslConnectorProperties(`value`: List<MapperDslConnectorPropertiesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("trpjedvfgegpbfqo")
    public suspend
    fun dslConnectorProperties(argument: List<suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("wgwtcgkwxyiesbap")
    public suspend fun dslConnectorProperties(
        vararg
        argument: suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param argument List of name/value pairs for connection properties.
     */
    @JvmName("sejfekpfbdgpnbkj")
    public suspend
    fun dslConnectorProperties(argument: suspend MapperDslConnectorPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            MapperDslConnectorPropertiesArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.dslConnectorProperties = mapped
    }

    /**
     * @param values List of name/value pairs for connection properties.
     */
    @JvmName("vrnhisldnwgisuqu")
    public suspend fun dslConnectorProperties(vararg values: MapperDslConnectorPropertiesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dslConnectorProperties = mapped
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("syojwcnvxgjbulck")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value List of columns for the source table.
     */
    @JvmName("bxdcbotsnkiqnbji")
    public suspend fun schema(`value`: List<MapperTableSchemaArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("jtcekernenmydirp")
    public suspend fun schema(argument: List<suspend MapperTableSchemaArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MapperTableSchemaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("lunydjwdnbybhfir")
    public suspend fun schema(vararg argument: suspend MapperTableSchemaArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            MapperTableSchemaArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param argument List of columns for the source table.
     */
    @JvmName("nlluaoggcnalinsq")
    public suspend fun schema(argument: suspend MapperTableSchemaArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MapperTableSchemaArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.schema = mapped
    }

    /**
     * @param values List of columns for the source table.
     */
    @JvmName("ltpdgxjvkmyawynd")
    public suspend fun schema(vararg values: MapperTableSchemaArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schema = mapped
    }

    internal fun build(): MapperTableArgs = MapperTableArgs(
        dslConnectorProperties = dslConnectorProperties,
        name = name,
        schema = schema,
    )
}
